---
title: ECA Library - Switch Case Default
version: v2
tags:
- bpmn
- library
- simple
- switch-case-default
- if-elsif-else
- PHP
- programming
---
# Switch Case Default

Version v2

<script>url='bpmn_io-eca_lib_0004.xml';archive='bpmn_io-eca_lib_0004.tar.gz'</script>
{!include/library/viewer.html!}

Instead of downloading the archive, you can download and apply this model as a recipe (Drupal 10.3 or later):

```shell
composer require drupal-eca-recipe/eca_lib_0004
cd web && php core/scripts/drupal recipe ../vendor/drupal-eca-recipe/eca_lib_0004
```

## Purpose

Demonstrate how typical switch-case PHP constructors could be simulated in ECA models - similar to if-elsif-else statements.

The model is similar to what you would normally do in PHP like this:

```php
switch ($field_select) {
  case &#039;a1&#039;:
  case &#039;a2&#039;:
  case &#039;a3&#039;:
  case &#039;c7&#039;:
    // Set Status to 3
    $field_status = 3;

  case &#039;b1&#039;:
  case &#039;b2&#039;:
    // Set Status to 4
    $field_status = 4;

  default:
    // Set default Status
    $field_status = 2;
}
```

Important note: after the action &quot;Set default Status to 2&quot;, ECA first checks the conditions of ALL successors; only then does it execute the actions that follow for those conditions that return TRUE. That&#039;s why the &quot;no condition&quot; link has no condition, as we want to execute that path in any case, but not before the top two paths had a chance to change the status. Therefore the condition, if the status is still 2, happens with a delay, i.e. really after everything else has been completed.

## Dependencies

- config
    - node.type.article
- module
    - eca_base
    - eca_content

## Used plugins

### Events

- [Presave content entity (Content: Article)](/plugins/eca/content/events/content_entity_presave.md)

### Conditions

- [Entity: compare field value](/plugins/eca/content/conditions/eca_entity_field_value.md)
- [Compare two scalar values](/plugins/eca/base/conditions/eca_scalar.md)

### Actions

- [Set Status to 3](/plugins/eca/content/actions/eca_set_field_value.md)
- [Set Status to 4](/plugins/eca/content/actions/eca_set_field_value.md)
- [Set default Status to 2](/plugins/eca/content/actions/eca_set_field_value.md)
- [Message containing status value](/plugins/core/actions/action_message_action.md)

## Changelog

`v1`

:   Initial version

`v2`

:   Add the &quot;no condition&quot; for the default value
